ApiSdk class

The repository of the endpoint

ApiSdk is the repository of the endpoint

Implemented types

Constructors

ApiSdk()

Properties

debug bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required EndpointConfig endpoint}) Future<ResponseApiSdk>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited