ApiSdkRepository class abstract

The repository of the endpoint

ApiSdkRepository is the repository of the endpoint

Implementers

Constructors

ApiSdkRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({required EndpointConfig endpoint}) Future<ResponseApiSdk>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited