EndpointConfig class abstract

The endpoint class to extend

Constructors

EndpointConfig()

Properties

body Map<String, dynamic>
getter/setter pair
bodyType BodyType
no setter
files List<ImagesModelEndpoint>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
getter/setter pair
method Method
no setter
path String
no setter
queryParameters Map<String, dynamic>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setBaseUrl String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited