ImagesModelEndpoint class

The file of the endpoint

ImagesModelEndpoint is the file of the endpoint

Constructors

ImagesModelEndpoint({required String path, required String key, String? url, MediaType? contentType})
ImagesModelEndpoint.fromJson(Map<String, dynamic> json)
factory

Properties

contentType ↔ MediaType?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String
getter/setter pair
path String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited