ResponseApiSdk class
The response of the endpoint
ResponseApiSdk is the response of the endpoint
Constructors
-
ResponseApiSdk({required dynamic body, required int statusCode, Map<
String, String> ? headers = const {}}) -
ResponseApiSdk.fromJson(Map<
String, dynamic> json) -
factory
Properties
- body ↔ dynamic
-
The body of the response
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> ? -
the headers of the response
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
The status code of the response
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited